FormValidatorLocale class abstract

Constructors

FormValidatorLocale()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

email(String v) → String
ip(String v) → String
ipv6(String v) → String
maxLength(String v, int n) → String
minLength(String v, int n) → String
name() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
phoneNumber(String v) → String
required() → String
toString() → String
A string representation of this object.
inherited
url(String v) → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited